@@ -1,7 +1,7 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/ce_parser.h,v 1.9 2006/01/09 16:30:20 richb Exp $
+/*  $Header$
  *
- *  Copyright (C) 2004-2006 Sami Pietila
+ *  Copyright (C) 2004-2008 Sami Pietila
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -36,6 +36,7 @@
 
 extern struct parser_state parser_state;
 
+int celex();
 int ceerror();                   /* dummy definition TODO: this is a douple */
 int ceparse();                   /* dummy definition. */
 int ceerror(char *s);
@@ -44,7 +45,7 @@ int ce_udf_parse(char *expression);
 
 void reset_ce_tokeniser();
 
-/* UTILITY NEEDED BECAUSE GNU SOURCE NOT ALWAYS AWAILABLE. */
+/* UTILITY NEEDED BECAUSE GNU SOURCE NOT ALWAYS AVAILABLE. */
 
 static inline char *
 ce_strndup(char *str, int len)
