@@ -25,39 +25,43 @@
 #define MP_SIZE      1000     /* Size of the multiple precision values. */
 
 void mperr();
-int mpeq(int *, int *);
-int mpge(int *, int *);
-int mpgt(int *, int *);
-int mple(int *, int *);
-int mplt(int *, int *);
-void mpabs(int *, int *);
+
+int mp_is_equal(const int *, const int *);
+int mp_is_greater_equal(const int *, const int *);
+int mp_is_greater_than(const int *, const int *);
+int mp_is_less_equal(const int *, const int *);
+int mp_is_less_than(const int *, const int *);
+
+double mp_cast_to_double(const int *);
+int    mp_cast_to_int(const int *);
+void   mp_set_from_double(double, int *);
+void   mp_set_from_integer(int, int *);
+void   mp_set_from_mp(const int *, int *);
+
+void mp_abs(const int *, int *);
+void mp_invert_sign(const int *, int *);
+
 void mpadd(int *, int *, int *);
-void mpaddi(int *, int *, int *);
+void mpaddi(int *, int, int *);
 void mpasin(int *, int *);
 void mpatan(int *, int *);
-void mpcdm(double *, int *);
-void mpcim(int *, int *);
-void mpcmd(int *, double *);
 void mpcmf(int *, int *);
-void mpcmi(int *, int *);
 void mpcmim(int *, int *);
 void mpcos(int *, int *);
 void mpcosh(int *, int *);
 void mpdiv(int *, int *, int *);
-void mpdivi(int *, int *, int *);
+void mpdivi(int *, int, int *);
 void mpexp(int *, int *);
 void mpln(int *, int *);
 void mpmul(int *, int *, int *);
-void mpmuli(int *, int *, int *);
-void mpneg(int *, int *);
+void mpmuli(int *, int, int *);
 void mppi(int *);
-void mppwr(int *, int *, int *);
+void mppwr(int *, int, int *);
 void mppwr2(int *, int *, int *);
 void mpset(int *, int *, int *);
 void mpsin(int *, int *);
 void mpsinh(int *, int *);
 void mpsqrt(int *, int *);
-void mpstr(int *, int *);
 void mpsub(int *, int *, int *);
 void mptanh(int *, int *);
 
